package icu.fur93.esp32_car.page

import android.widget.Toast
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.height
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.vector.ImageVector
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.vectorResource
import androidx.compose.ui.unit.dp
import icu.fur93.esp32_car.R
import icu.fur93.esp32_car.Route
import icu.fur93.esp32_car.provider.LocalNavigation
import icu.fur93.esp32_car.repository.ConnectionState
import icu.fur93.esp32_car.ui.card.UnconnectedStatusCard
import icu.fur93.esp32_car.ui.component.CardButtonGroup
import icu.fur93.esp32_car.ui.component.CardButtonItem
import icu.fur93.esp32_car.ui.component.PageTitle
import icu.fur93.esp32_car.ui.theme.LayoutContentModifier
import icu.fur93.esp32_car.viewmodel.CarViewModel

@Composable
fun ControlPage(viewModel: CarViewModel) {
    val connectionState by viewModel.connectionState.collectAsState()

    Column(LayoutContentModifier) {
        PageTitle(Route.Control.title)
        if (connectionState == ConnectionState.CONNECTED) {
            ControlPageStatusCard()
        } else {
            UnconnectedStatusCard(viewModel)
        }
    }
}

@Composable
fun ControlPageStatusCard() {
    ControlPageAutoControl()
    Spacer(Modifier.height(18.dp))
    ControlPageManualControl()
}

@Composable
fun ControlPageAutoControl() {
    val context = LocalContext.current
    return CardButtonGroup(
        title = "自动控制",
        buttons = listOf(
            CardButtonItem(
                text = Route.ControlPathfinderMode.title,
                icon = ImageVector.vectorResource(R.drawable.outline_route_24),
                onClick = {
                    Toast.makeText(context, "暂未实现", Toast.LENGTH_SHORT).show()
                }
            )
        )
    )
}

@Composable
fun ControlPageManualControl() {
    val context = LocalContext.current
    val navController = LocalNavigation.current
    CardButtonGroup(
        title = "手动控制",
        buttons = listOf(
            CardButtonItem(
                text = Route.ControlSingleJoystickMode.title,
                icon = ImageVector.vectorResource(R.drawable.outline_joystick_24),
                onClick = {
                    navController.navigate(Route.ControlSingleJoystickMode.route)
                }
            ),
            CardButtonItem(
                text = Route.ControlGamepadMode.title,
                icon = ImageVector.vectorResource(R.drawable.outline_gamepad_24),
                onClick = {
                    navController.navigate(Route.ControlGamepadMode.route)
                }
            ),
            CardButtonItem(
                text = "陀螺仪模式",
                icon = ImageVector.vectorResource(R.drawable.motion_sensor_active_24),
                onClick = {
                    Toast.makeText(context, "暂未实现", Toast.LENGTH_SHORT).show()
                }
            )
        )
    )
}