package icu.fur93.esp32_car.page

import androidx.compose.foundation.layout.Column
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import icu.fur93.esp32_car.repository.ConnectionState
import icu.fur93.esp32_car.ui.card.UnconnectedStatusCard
import icu.fur93.esp32_car.ui.carditem.StatusCardInfo
import icu.fur93.esp32_car.ui.carditem.StatusCardInfraredStatus
import icu.fur93.esp32_car.ui.carditem.StatusCardMotorStatus
import icu.fur93.esp32_car.ui.carditem.StatusCardUltrasoundStatus
import icu.fur93.esp32_car.ui.component.PageTitle
import icu.fur93.esp32_car.ui.component.StatusCard
import icu.fur93.esp32_car.ui.theme.LayoutContentModifier
import icu.fur93.esp32_car.viewmodel.CarViewModel

@Composable
fun HomePage(viewModel: CarViewModel) {
    val connectionState by viewModel.connectionState.collectAsState()

    Column(LayoutContentModifier) {
        PageTitle("标题还没想好")
        if (connectionState == ConnectionState.CONNECTED) {
            HomePageStatusCard(viewModel)
        } else {
            UnconnectedStatusCard(viewModel)
        }
    }
}

@Composable
fun HomePageStatusCard(viewModel: CarViewModel) {
    val deviceInfo by viewModel.connectionInfoState.collectAsState()
    val carState by viewModel.carState.collectAsState()

    StatusCard(
        cardItems = listOf(
            StatusCardInfo(deviceInfo),
            StatusCardMotorStatus(carState),
            StatusCardInfraredStatus(carState.infraredState),
            StatusCardUltrasoundStatus(carState.ultrasoundState)
        )
    )
}
