package icu.fur93.esp32_car.ui.component

import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.Send
import androidx.compose.material.icons.automirrored.outlined.Send
import androidx.compose.material.icons.filled.Home
import androidx.compose.material.icons.filled.Settings
import androidx.compose.material.icons.outlined.Home
import androidx.compose.material.icons.outlined.Settings
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.NavigationBar
import androidx.compose.material3.NavigationBarItem
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.ui.graphics.vector.ImageVector
import androidx.navigation.NavHostController
import icu.fur93.esp32_car.Route

data class BottomNavigationItem(
    val icon: ImageVector,
    val selectedIcon: ImageVector,
    val route: Route
)

@Composable
fun BottomNavigationBar(
    navController: NavHostController,
    navItems: List<BottomNavigationItem>
) {
    val currentRoute = navController
        .currentBackStackEntryFlow
        .collectAsState(initial = navController.currentBackStackEntry)
        .value?.destination?.route

    NavigationBar(
        containerColor = MaterialTheme.colorScheme.surface,
    ) {
        navItems.forEachIndexed { _, item ->
            NavigationBarItem(
                icon = {
                    Icon(
                        if ((currentRoute
                                ?: "").startsWith(item.route.route)
                        ) item.selectedIcon else item.icon, item.route.title
                    )
                },
                label = { Text(item.route.title) },
                selected = (currentRoute?:"").startsWith(item.route.route),
                onClick = {
                    navController.navigate(item.route.route) {
                        // 弹出到导航图的起始位置
                        popUpTo(item.route.route) { inclusive = true }
                        launchSingleTop = true
                        // 避免创建同一目标的多个副本
                        launchSingleTop = true
                        // 恢复之前的状态
                        restoreState = false
                    }
                }
            )
        }
    }
}