package icu.fur93.esp32_car.ui.component

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.lazy.grid.GridCells
import androidx.compose.foundation.lazy.grid.LazyVerticalGrid
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Card
import androidx.compose.material3.ElevatedCard
import androidx.compose.material3.FilledTonalButton
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.material3.contentColorFor
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.vector.ImageVector
import androidx.compose.ui.unit.dp
import icu.fur93.esp32_car.ui.theme.CardButtonTypography

data class CardButtonItem(
    val text: String,
    val icon: ImageVector,
    val onClick: (() -> Unit)? = null,
    val modifier: Modifier? = Modifier
)

val CardButtonGroupGap = 10.dp

@Composable
fun CardButtonGroup(
    title: String,
    buttons: List<CardButtonItem>
) {
    Text(
        text = title,
        style = MaterialTheme.typography.titleLarge
    )
    Spacer(Modifier.height(CardButtonGroupGap))
    LazyVerticalGrid(
        columns = GridCells.Fixed(2),
        horizontalArrangement = Arrangement.spacedBy(CardButtonGroupGap),
        verticalArrangement = Arrangement.spacedBy(CardButtonGroupGap)
    ) {
        items(buttons.size) { index ->
            CardButton(buttons[index])
        }
    }
}

@Composable
fun CardButton(
    item: CardButtonItem
) {
    Button(
        onClick = { item.onClick?.invoke() },
        shape = MaterialTheme.shapes.medium,
        colors = ButtonDefaults.buttonColors(
            containerColor = MaterialTheme.colorScheme.surfaceVariant,
            contentColor = MaterialTheme.colorScheme.contentColorFor(MaterialTheme.colorScheme.surfaceVariant)
        )
    ) {
        Column(
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 10.dp, bottom = 10.dp),
            verticalArrangement = Arrangement.SpaceBetween
        ) {
            Text(
                text = item.text,
                style = CardButtonTypography.CardButtonItemTextStyle
            )
            Spacer(Modifier.height(10.dp))
            Box(
                modifier = Modifier.fillMaxWidth(),
                contentAlignment = Alignment.BottomEnd
            ) {
                Icon(
                    imageVector = item.icon,
                    contentDescription = item.text,
                    modifier = Modifier.size(24.dp),
                    tint = MaterialTheme.colorScheme.primary
                )
            }
        }
    }
}