package icu.fur93.esp32_car.ui.component

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Card
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import icu.fur93.esp32_car.ui.theme.CardTypography

data class CardItem(
    val title: String,
    val content: @Composable () -> Unit
)

@Composable
fun StatusCard(
    cardItems: List<CardItem>,
    bottomControl: @Composable() (() -> Unit?)? = null
) {
    Card (
        modifier = Modifier.fillMaxWidth()
    ) {
        Column(Modifier.fillMaxWidth().padding(20.dp)) {
            cardItems.forEachIndexed { index, item ->
                StatusCardTitle(item.title)
                Spacer(Modifier.height(2.dp))
                item.content()
                if (index != cardItems.size - 1) {
                    Spacer(Modifier.height(16.dp))
                }
            }
            if (bottomControl != null) {
                Spacer(Modifier.height(20.dp))
                Row (
                    modifier = Modifier.fillMaxWidth(),
                    horizontalArrangement = Arrangement.End
                ) {
                    bottomControl()
                }
            }
        }
    }
}

@Composable
fun StatusCardTitle (
    text: String
) {
    Text(
        text = text,
        style = CardTypography.TitleTextStyle
    )
}

@Composable
fun StatusCardItemText (
    text: String
) {
    Text(
        text = text,
        style = CardTypography.ItemTextStyle
    )
}